@@ -15,10 +15,10 @@ def custom_static(path):
     :param path: path of static file
     :return: path of static file
     """
-    custom_path = 'custom/' + path
     milea_path = 'milea/' + path
-    if finders.find(custom_path):
-        return core_settings.STATIC_URL + custom_path
+
+    if finders.find(path):
+        return core_settings.STATIC_URL + path
     else:
         return core_settings.STATIC_URL + milea_path
 
